# kkmh-js-sdk API 文档

## 一.基础类

### 1.引入方式  
建议在头部加载,不依赖其它框架 

```
cdn:
<script src="https://jssdk.kkmh.com/js/kkmh-js-sdk.1.0.1.js"></script>

非cdn:
<script src="https://jssdk.kuaikanmanhua.com/js/kkmh-js-sdk.1.0.1.js"></script>
```
####  1.1 m站链接:
- 首页:https://m.kuaikanmanhua.com
- 专题页:https://m.kuaikanmanhua.com/mobile/{专题id}/list/
- 章节页:https://m.kuaikanmanhua.com/mobile/comics/{章节id}
-------------------------------
### 2.数据返回格式
```
成功接收:
{
    code    : 200,
    data    : {}, 
    message : '成功信息'
}

失败接收:
{
    code:100404|100401|1002005|100400|100409|200400,
    data:{},
    message:'失败信息'
}
```
--------------------------------
### 3.code 注解

|   code     |  message   |      备注       |
|:----------:|:----------:|----------------|  
| 200        | ok         | 请求成功        |
| 100404     | not found  | 表示未支持此协议 |
| 100401     | 未登录      | 未登录         |
| 1002005    | 异常失败    | 异常失败        |
| 100400     | bad request|参数异常         |
| 100409     | bad request|找不到指定页面    |
| 200400     | bad request|参数未传递       |

### 4.全局实例对象 window.kkmhSDk 
- 包含所有sdk函数,请勿修改
- var kkmhSDk = window.kkmhSDk 


## 5.API预览 
```
kkmhSDk.getAppUA 
kkmhSDk.openAppTopic
kkmhSDk.openAppComic
kkmhSDk.openWebview 
kkmhSDk.openH5kkConvert
kkmhSDk.openH5FillAddress
kkmhSDk.nativeShare
kkmhSDk.getSysInfo
kkmhSDk.openAppLogin
kkmhSDk.getUuid 
```
---------------------------------------------

## 二.API

### 1.获取信息


> 1.1 kkmhSDk.getAppUA 当前用户的运行环境是否在快看客户端内

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

#### 示例代码
````
调用方式:
kkmhSDk.getAppUA({
  success:function(res){},
  error:function(err){}
})

成功接收:
{
    code:200,
    data:{
        iphone 是否是 ios 系统
        android 是否是 android 系统
        kkmh  是否是 快看app内运行
        version  0|版本号    0:不是app或者获取版本号错误
    },
    message:'ok'
}
````




>1.2 kkmhSDk.getUuid 获取登录状态&判断是否登录

#### 支持版本
- Android : 537000
- IOS : 537000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| appid     |string   |   ''    |是    |商户ID                      |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

````
调用方式:
kkmhSDk.getUuid({
  appid:'appid',
  success:function(res){},
  error:function(err){}
})

成功接收:
{
    code:200,
    data:{
        uuid:1234 
    },
    message:'ok'
}
````



>1.3 kkmhSDk.getSysInfo 获取客户端版本号

#### 支持版本
- Android : 510000
- IOS : 537000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

````
调用方式:
kkmhSDk.getSysInfo({
  success:function(res){},
  error:function(err){}
})

成功接收:
{
    code:200,
    data:{
        model: '', //手机型号
        pixelRatio: '', //设备像素比
        windowWidth: '', //窗口宽度
        windowHeight: '', //窗口高度
        language: '', //设置的语言
        version: '', //版本号
    },
    message:'ok'
}
````


------------------------------------
### 2.监听H5启动或切前台(显示页面)
>2.1 kkmhSDk.appOnShow 显示页面接收消失的回调函数

#### 支持版本
- Android : 523000
- IOS : 523000

#### 参数
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| callback  |function |   无    |是    |接口调用成功的回调函数         |
建议一个页面设置一次 
```
调用方式:
kkmhSDk.appOnShow(function(res){
    ......
})
```



--------------------------------------
### 3.Native - 跳转
>3.1 kkmhSDk.openAppTopic Native-打开漫画专题页

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| id        |str/num  |   ''    |是    |漫画专题Id                   |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

```
调用方式:
kkmhSDk.openAppTopic({
    id:123,
    success:function(res){},
    error:function(err){}
})

成功接收:
{
    code:200,
    data:{},
    message:'ok'
}
```



>3.2 kkmhSDk.openAppComic Native-漫画章节页

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| id        |str/num  |   ''    |是    |漫画章节Id                   |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

```
调用方式:
kkmhSDk.openAppComic({
    id:123,
    success:function(res){},
    error:function(err){}
})

成功接收:
{
    code:200,
    data:{},
    message:'ok'
}
```



> 3.3 kkmhSDk.openAppLogin 打开快看登录界面

#### 支持版本
- Android : 401000
- IOS : 430000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |
```
调用方式:
kkmhSDk.openAppLogin({
    success:function(res){},
    error:function(err){}
})

成功接收:
{
    code:200,
    data:{
      status: 1, 0:用户未登录 ; 1:用户已登录
    },
    message:'ok'
}
```



--------------------------------------------------
### 4.Native - 分享
>4.1  kkmhSDk.nativeShare 分享 - 分享到微博、qq空间、微信朋友圈、微信好友

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| title     |string   |   无    |是    |分享标题                   |
| desc      |string   |   无    |是    |分享描述                   |
|shareImageUrl|string |   ''    |否    |分享的图片地址              |
|iconUrl   |string    | 快看icon |否    |icon图标地址               |
|link       |string   |快看H5官网|否    |分享后点击跳转链接地址        |
|type       |number   |     0  |否    |分享类型,0 分享为网页 1 分享为图片|
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |
```
调用方式:
kkmhSDk.nativeShare({
    title:'快看漫画', 
    desc:'快看漫画是是引领行业的新生代漫画阅读平台和兴趣社区。它为用户提供优质原创漫画内容，营造良好的二次元社区氛围，成为年轻一代的潮流文化阵地。',   
    link:'https://m.kuaikanmanhua.com/', 
    success:function(res){},
    error:function(err){}
})

成功接收:
{
    code:200,
    data:{
        type: type为before表示分享窗口被调起的行为，type为after表示分享结果行为
        link: 被分享的链接
        result: 操作结果，若type=before，result=1表示分享窗口调起成功，result=0表示分享窗口调起失败；如type=after，result=1表示分享成功，result=0表示分享失败, 2表示分享被取消；
        platform: Wechat，微信；WechatMoments，微信朋友圈；SinaWeibo，新浪微博；QZone，QQ朋友圈；QQ
    },
    message:'ok'
}
```


---------------------------------------

### 5. native 新开 webview窗口打开 web页面
>5.1 kkmhSDk.openWebview  新开webview页面 

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| url       |string   |   ''    |是    | 新打开链接地址              |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

```
调用方式:
kkmhSDk.openWebview({
    url:'https://www.baidu.com/',
    success:function(res){},
    error:function(err){}
})

成功接收:
{
    code:200,
    data:{
      status : 1 // 1.成功呼起，2.成功退出或关掉
    },
    message:'ok'
}
```

>5.2 kkmhSDk.openH5kkConvert  打开web KK币兑换码兑换页

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| id        |str/num  |   ''    |是    |漫画专题Id                   |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

```
调用方式:
kkmhSDk.openH5kkConvert({
    success:function(res){},
    error:function(err){}
})

成功接收:同kkmhSDk.openH5Topic成功接收
```


>5.3 kkmhSDk.openH5FillAddress  打开web 填写地址信息页

#### 支持版本
- Android : 510000
- IOS : 510000

#### 参数 Object object
|   属性     |   类型   |  默认值  |  必填 |         说明              |
|:---------:|:-------:|---------|------|---------------------------|
| appid     |string   |   ''    |是    |商户ID                      |
| success   |function |   无    |是    |接口调用成功的回调函数         |
| error     |function |   无    |是    |接口调用失败的回调函数         |

```
调用方式:
kkmhSDk.openH5FillAddress({
    appid:'123'
    success:function(res){},
    error:function(err){}
})

成功接收:同kkmhSDk.openH5Topic成功接收
```




# 服务端Api
#### 1. 校验uuid  
> appid激活期间校验uuid有效性  
##### 请求URL：/v3/ad/h5/user/check
##### 请求方法：GET

#### 请求参数
|   请求参数  |   描述   |  类型  |  必填 |         备注              |
|:---------:|:-------:|---------|------|---------------------------|
| appid     |项目ID    | String  |是    | 线下分配不同项目的id         |
| uuid      |获取uuid  | String  |是    |16位字符串                   |

#### 响应参数
|   响应参数  |   描述   |  类型  |  必填 |         备注              |
|:---------:|:-------:|---------|------|---------------------------|
| status     |        | int     |是    | 0:无效, 1:有效             |

```
https://h5.kuaikanmanhua.com/v3/ad/h5/user/check?appid={appid}&uuid={uuid}

{
    "code": 200, 
    "data": {
        "status": 0
    },
    "message": "ok"
}

```